@@ -21,11 +21,7 @@ static void ensure_capacity(Array *arr, uint32_t new_capacity) {
         }
     }
 
-    if (arr->buf == NULL) {
-        arr->buf = malloc(arr->capacity * sizeof(void*));
-    } else {
-        arr->buf = realloc(arr->buf, arr->capacity * sizeof(void*));
-    }
+    arr->buf = realloc(arr->buf, arr->capacity * sizeof(void*));
 
     //clear the new part of the array
     memset(&arr->buf[old_capacity], 0, (arr->capacity - old_capacity) * sizeof(void*));
