@@ -308,9 +308,7 @@ static void deleteObject(NVDriver *drv, VAGenericID id) {
     ARRAY_FOR_EACH(Object, o, &drv->objects)
         if (o->id == id) {
             remove_element_at(&drv->objects, o_idx);
-            if (o->obj != NULL) {
-                free(o->obj);
-            }
+            free(o->obj);
             free(o);
             //we've found the object, no need to continue
             break;
@@ -1043,12 +1041,12 @@ static VAStatus nvCreateContext(
         cfg->bitDepth = surface->bitDepth;
     }
 
-    if (drv->surfaceCount == 0 && num_render_targets == 0) {
-        LOG("0 surfaces have been passed to vaCreateContext, this might cause errors. Setting surface count to 32");
+    if (drv->surfaceCount <= 1 && num_render_targets == 0) {
+        LOG("0/1 surfaces have been passed to vaCreateContext, this might cause errors. Setting surface count to 32");
         num_render_targets = 32;
     }
 
-    int surfaceCount = drv->surfaceCount != 0 ? drv->surfaceCount : num_render_targets;
+    int surfaceCount = drv->surfaceCount > 1 ? drv->surfaceCount : num_render_targets;
     if (surfaceCount > 32) {
         LOG("Application requested %d surface(s), limiting to 32. This may cause issues.", surfaceCount);
         surfaceCount = 32;
@@ -1065,14 +1063,13 @@ static VAStatus nvCreateContext(
         .ChromaFormat        = cfg->chromaFormat,
         .OutputFormat        = cfg->surfaceFormat,
         .bitDepthMinus8      = cfg->bitDepth - 8,
-        .DeinterlaceMode     = cudaVideoDeinterlaceMode_Adaptive,
+        .DeinterlaceMode     = cudaVideoDeinterlaceMode_Weave,
 
         //we only ever map one frame at a time, so we can set this to 1
         //it isn't particually efficient to do this, but it is simple
         .ulNumOutputSurfaces = 1,
         //just allocate as many surfaces as have been created since we can never have as much information as the decode to guess correctly
         .ulNumDecodeSurfaces = surfaceCount,
-
     };
 
     //reset this to 0 as there are some cases where the context will be destroyed but not terminated, meaning if it's initialised again
@@ -2082,7 +2079,7 @@ static VAStatus nvExportSurfaceHandle(
 
     drv->backend->fillExportDescriptor(drv, surface, ptr);
 
-    //LOG("Exporting with w:%d h:%d o:%d p:%d m:%" PRIx64 " o:%d p:%d m:%" PRIx64, ptr->width, ptr->height, ptr->layers[0].offset[0],
+    // LOG("Exporting with w:%d h:%d o:%d p:%d m:%" PRIx64 " o:%d p:%d m:%" PRIx64, ptr->width, ptr->height, ptr->layers[0].offset[0],
     //                                                             ptr->layers[0].pitch[0], ptr->objects[0].drm_format_modifier,
     //                                                             ptr->layers[1].offset[0], ptr->layers[1].pitch[0],
     //                                                             ptr->objects[1].drm_format_modifier);
@@ -2115,6 +2112,8 @@ static VAStatus nvTerminate( VADriverContextP ctx )
     CHECK_CUDA_RESULT_RETURN(cu->cuCtxDestroy(drv->cudaContext), VA_STATUS_ERROR_OPERATION_FAILED);
     drv->cudaContext = NULL;
 
+    free(drv);
+
     return VA_STATUS_SUCCESS;
 }
 
